nbxmpp.c14n

Package nbxmpp :: Module c14n |
[hide private]
[frames] | no frames]

# Module c14n

source code

XML canonicalisation methods (for XEP-0116)

Functions | [hide private]
c14n(node, is_buggy) | source code
normalise_attr(val) | source code
normalise_text(val) | source code

Variables | [hide private]
| __package__ = ``'``nbxmpp``'``

Imports: ustr

Function Details | [hide private]

### c14n(node, is_buggy) | source code

### normalise_attr(val) | source code

### normalise_text(val) | source code

Variables Details | [hide private]

  ### __package__ Value:
      'nbxmpp'